@@ -497,10 +497,10 @@ class DynamicSetting(object):
             return False, f'All values should be {type.__name__}'
         return True, None
 
-    def health(self):
+    def health(self, verbose=False):
 
         if self.content is None:
-            self.get(version=self.debug_version)
+            self.get(version=self.debug_version, verbose=verbose)
 
         healthy = False
 
